@@ -18,11 +18,18 @@ G_BEGIN_DECLS
 G_DECLARE_FINAL_TYPE (PhoshBackgroundCache, phosh_background_cache, PHOSH, BACKGROUND_CACHE, GObject)
 
 PhoshBackgroundCache         *phosh_background_cache_get_default       (void);
-void                          phosh_background_cache_fetch_background  (PhoshBackgroundCache *self,
+void                          phosh_background_cache_fetch_async       (PhoshBackgroundCache *self,
                                                                         GFile                *file,
-                                                                        GCancellable         *cancel);
+                                                                        GCancellable         *cancel,
+                                                                        GAsyncReadyCallback   callback,
+                                                                        gpointer              user_data);
+PhoshBackgroundImage *        phosh_background_cache_fetch_finish      (PhoshBackgroundCache *self,
+                                                                        GAsyncResult         *res,
+                                                                        GError              **error);
 PhoshBackgroundImage         *phosh_background_cache_lookup_background (PhoshBackgroundCache *self,
                                                                         GFile                *file);
+void                          phosh_background_cache_remove            (PhoshBackgroundCache *self,
+                                                                        GFile                *file);
 void                          phosh_background_cache_clear_all         (PhoshBackgroundCache *self);
 
 G_END_DECLS
